import { AxiosInstance } from "axios";
import { RequestHandler } from "express";
export declare enum Methods {
    POST = "POST",
    PUT = "PUT",
    DELETE = "DELETE",
    PATCH = "PATCH",
    GET = "GET"
}
export type RoutePermission = {
    method: Methods;
    path: string;
};
export type Scopes = {
    [domain: string]: RoutePermission[];
};
export type JwtPayload = {
    service_from: string;
    service_to: string;
    scope: RoutePermission[];
};
export type ServiceMeta = {
    clientPrivateKey: string;
    portalPublicKey: string;
    serviceId: string;
};
export type PortalOptions = {
    hostname?: string;
    clientId: string;
    clientSecret: string;
    label?: string;
    description?: string;
    host?: string;
};
export declare class CrysteamPortal {
    private _ID;
    private readonly _tokenCache;
    private readonly _cryptrack;
    private readonly _axios;
    private readonly _hostname?;
    private readonly _host;
    private readonly _secretKey;
    constructor(options: PortalOptions);
    getScopes(): Promise<Scopes>;
    getToken(): Promise<string>;
    registerService(label: string, description?: string, force?: boolean): Promise<void>;
    generateAccessToken(serviceFrom: string, scope: RoutePermission[]): Promise<string>;
    getServiceScopesFor(domain: string): Promise<RoutePermission[]>;
    isScopeAllowed(scopes: RoutePermission[], permission: RoutePermission): boolean;
    isScopeAllowed(domain: string, permission: RoutePermission): Promise<boolean>;
    createHttpClientFor(serviceFrom: string, scope: RoutePermission[]): AxiosInstance;
    verifyApiKey(): RequestHandler;
}
